==> chaotic_helper-1.10.1.tar.gz: lib/init/files_templates.dart <==
part of init;

const _analysisOptionsTemp = '''
include: package:lint/analysis_options.yaml

linter:
  rules:
    avoid_setters_without_getters: false
    avoid_positional_boolean_parameters: false
    sort_pub_dependencies: false
    directives_ordering: false

analyzer:
  errors:
    unused_import: warning

  strong-mode:
    implicit-casts: true
''';

const _cmdCommandsTemp = '''
flutter pub add lint
flutter pub add bot_toast
flutter pub add sizer
flutter pub add get
flutter pub add provider
flutter pub add easy_localization
flutter pub add chaotic
flutter pub add easy_logger
flutter pub get
''';

const _assetsTemp = '''
  
  assets:
    - assets/lang/
''';

final _mainTemp = '''
import 'package:bot_toast/bot_toast.dart';
import 'package:easy_localization/easy_localization.dart';
import 'package:get/get.dart';
import 'package:sizer/sizer.dart';
import 'package:easy_logger/easy_logger.dart';
${Chaotic._applicationFile ?? '''
import 'package:provider/provider.dart';
import 'src/screen/screens.dart';
import 'package:chaotic/commons.dart';
import 'package:flutter/material.dart';
'''}


Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await EasyLocalization.ensureInitialized();
  EasyLocalization.logger.enableLevels = [
    LevelMessages.error,
    LevelMessages.warning,
  ];
  Provider.debugCheckInvalidValueType = null;
  
  runApp(
    EasyLocalization(
      supportedLocales: const [
        Locale('en'),
        Locale('ar'),
      ],
      path: 'assets/lang',
      fallbackLocale: const Locale('en'),
      child: MyApp(),
    ),
  );
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Sizer(
      builder: (context, orientation, deviceType) => GetMaterialApp(
        builder: BotToastInit(),
        navigatorObservers: [BotToastNavigatorObserver()],
        localizationsDelegates: context.localizationDelegates,
        supportedLocales: context.supportedLocales,
        locale: context.locale,
        theme: ThemeData(
          pageTransitionsTheme: const PageTransitionsTheme(
            builders: {
              TargetPlatform.android: CupertinoPageTransitionsBuilder(),
              TargetPlatform.iOS: CupertinoPageTransitionsBuilder(),
            },
          ),
        ),
        home: ChangeNotifierProvider.value(
          value: SplashProvider(),
          child: SplashScreen(),
        ),
      ),
    );
  }
}
''';

const _arTemp = '''
{}
''';
const _enTemp = '''
{}
''';

const _applicationTemp = '''
export 'package:flutter/material.dart';
export 'package:provider/provider.dart';

// export 'common/commons.dart';
export 'screen/screens.dart';
// export 'widget/widgets.dart';
// export 'service/services.dart';
// export 'model/models.dart';

export 'package:chaotic/commons.dart';
export 'package:chaotic/services.dart';
export 'package:chaotic/widgets.dart';
''';

String _newScreenTemp(String screenNameCamelcase) {
  return '''
  ${Chaotic._applicationFile ?? '''
import 'package:provider/provider.dart';
import '../screens.dart';
import 'package:flutter/material.dart';
'''}


class ${screenNameCamelcase}Screen extends StatelessWidget {
  late ${screenNameCamelcase}Provider provider;
  
  @override
  Widget build(BuildContext context) {
    provider = context.watch<${screenNameCamelcase}Provider>();
    return const Scaffold(
      body: Center(child: Text('hello world, this is $screenNameCamelcase screen')),
    );
  }
}
  ''';
}

String _newProviderTemp(String screenNameCamelcase) {
  return '''
  ${Chaotic._applicationFile ?? '''
import 'package:flutter/material.dart';
'''}

class ${screenNameCamelcase}Provider extends ChangeNotifier{

}
  ''';
}

String _newWidgetTemp(String widgetName) {
  return '''
  ${Chaotic._applicationFile ?? '''
import 'package:flutter/material.dart';
'''}

class $widgetName extends StatelessWidget {

  @override
  Widget build(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.all(8.0),
      child: Text('$widgetName widget'),
    );
  }
}
  ''';
}

String _modelTemp(String modelName) => '''
import 'dart:convert';

extension ${modelName.toCamelcase()}Functions on ${modelName.toCamelcase()}{
}
class ${modelName.toCamelcase()}{
}
''';

String _newServiceTemp(String serviceName) {
  return '''
class ${serviceName}Service {
  ${serviceName}Service._();
  static final _instance = ${serviceName}Service._();
  factory ${serviceName}Service.getInstance() => _instance;
  //--------------------
}
  ''';
}

Future<void> _exportNewScreen(String screenName) async {
  final exportTemp = '''
  export '$screenName/$screenName.dart';
  export '$screenName/${screenName}_provider.dart';
''';
  await _screensFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewCommon(String commonName) async {
  final exportTemp = '''
  export '$commonName.dart';
''';
  await _commonsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewWidget(String widgetName) async {
  final exportTemp = '''
  export '$widgetName.dart';
''';
  await _widgetsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewModel(String modelName) async {
  final exportTemp = '''
  export '$modelName.dart';
''';
  await _modelsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewService(String serviceName) async {
  final exportTemp = '''
  export '$serviceName.dart';
''';
  await _servicesFile.writeAsString(exportTemp, mode: FileMode.append);
}

String _clearTemp(bool git) => '''
import 'package:chaotic_helper/init.dart';
import 'package:chaotic_helper/backend.dart';

Future<void> main() async {
  ${Chaotic.applicationName == null ? '' : 'Chaotic.applicationName = "${Chaotic.applicationName}";'}
  ${git ? 'Chaotic.useGit = true;' : ''}
  
  await Chaotic.clear();
}
''';

==> chaotic_helper-1.10.2.tar.gz: lib/init/files_templates.dart <==
part of init;

const _analysisOptionsTemp = '''
include: package:lint/analysis_options.yaml

linter:
  rules:
    avoid_setters_without_getters: false
    avoid_positional_boolean_parameters: false
    sort_pub_dependencies: false
    directives_ordering: false

analyzer:
  errors:
    unused_import: warning

  strong-mode:
    implicit-casts: true
''';

const _cmdCommandsTemp = '''
flutter pub add lint
flutter pub add bot_toast
flutter pub add sizer
flutter pub add get
flutter pub add provider
flutter pub add easy_localization
flutter pub add chaotic
flutter pub add easy_logger
flutter pub get
''';

const _assetsTemp = '''
  
  assets:
    - assets/lang/
''';

final _mainTemp = '''
import 'package:bot_toast/bot_toast.dart';
import 'package:easy_localization/easy_localization.dart';
import 'package:get/get.dart';
import 'package:sizer/sizer.dart';
import 'package:easy_logger/easy_logger.dart';
${Chaotic._applicationFile ?? '''
import 'package:provider/provider.dart';
import 'src/screen/screens.dart';
import 'package:chaotic/commons.dart';
import 'package:flutter/material.dart';
'''}


Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await EasyLocalization.ensureInitialized();
  EasyLocalization.logger.enableLevels = [
    LevelMessages.error,
    LevelMessages.warning,
  ];
  Provider.debugCheckInvalidValueType = null;
  
  runApp(
    EasyLocalization(
      supportedLocales: const [
        Locale('en'),
        Locale('ar'),
      ],
      path: 'assets/lang',
      fallbackLocale: const Locale('en'),
      child: MyApp(),
    ),
  );
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Sizer(
      builder: (context, orientation, deviceType) => GetMaterialApp(
        builder: BotToastInit(),
        navigatorObservers: [BotToastNavigatorObserver()],
        localizationsDelegates: context.localizationDelegates,
        supportedLocales: context.supportedLocales,
        locale: context.locale,
        theme: ThemeData(
          pageTransitionsTheme: const PageTransitionsTheme(
            builders: {
              TargetPlatform.android: CupertinoPageTransitionsBuilder(),
              TargetPlatform.iOS: CupertinoPageTransitionsBuilder(),
            },
          ),
        ),
        home: ChangeNotifierProvider( 
          create: (_) => SplashProvider(),
          child: SplashScreen(),
        ),
      ),
    );
  }
}
''';

const _arTemp = '''
{}
''';
const _enTemp = '''
{}
''';

const _applicationTemp = '''
export 'package:flutter/material.dart';
export 'package:provider/provider.dart';

// export 'common/commons.dart';
export 'screen/screens.dart';
// export 'widget/widgets.dart';
// export 'service/services.dart';
// export 'model/models.dart';

export 'package:chaotic/commons.dart';
export 'package:chaotic/services.dart';
export 'package:chaotic/widgets.dart';
''';

String _newScreenTemp(String screenNameCamelcase) {
  return '''
  ${Chaotic._applicationFile ?? '''
import 'package:provider/provider.dart';
import '../screens.dart';
import 'package:flutter/material.dart';
'''}


class ${screenNameCamelcase}Screen extends StatelessWidget {
  late ${screenNameCamelcase}Provider provider;
  
  @override
  Widget build(BuildContext context) {
    provider = context.watch<${screenNameCamelcase}Provider>();
    return const Scaffold(
      body: Center(child: Text('hello world, this is $screenNameCamelcase screen')),
    );
  }
}
  ''';
}

String _newProviderTemp(String screenNameCamelcase) {
  return '''
  ${Chaotic._applicationFile ?? '''
import 'package:flutter/material.dart';
'''}

class ${screenNameCamelcase}Provider extends ChangeNotifier{

}
  ''';
}

String _newWidgetTemp(String widgetName) {
  return '''
  ${Chaotic._applicationFile ?? '''
import 'package:flutter/material.dart';
'''}

class $widgetName extends StatelessWidget {

  @override
  Widget build(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.all(8.0),
      child: Text('$widgetName widget'),
    );
  }
}
  ''';
}

String _modelTemp(String modelName) => '''
import 'dart:convert';

extension ${modelName.toCamelcase()}Functions on ${modelName.toCamelcase()}{
}
class ${modelName.toCamelcase()}{
}
''';

String _newServiceTemp(String serviceName) {
  return '''
class ${serviceName}Service {
  ${serviceName}Service._();
  static final _instance = ${serviceName}Service._();
  factory ${serviceName}Service.getInstance() => _instance;
  //--------------------
}
  ''';
}

Future<void> _exportNewScreen(String screenName) async {
  final exportTemp = '''
  export '$screenName/$screenName.dart';
  export '$screenName/${screenName}_provider.dart';
''';
  await _screensFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewCommon(String commonName) async {
  final exportTemp = '''
  export '$commonName.dart';
''';
  await _commonsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewWidget(String widgetName) async {
  final exportTemp = '''
  export '$widgetName.dart';
''';
  await _widgetsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewModel(String modelName) async {
  final exportTemp = '''
  export '$modelName.dart';
''';
  await _modelsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewService(String serviceName) async {
  final exportTemp = '''
  export '$serviceName.dart';
''';
  await _servicesFile.writeAsString(exportTemp, mode: FileMode.append);
}

String _clearTemp(bool git) => '''
import 'package:chaotic_helper/init.dart';
import 'package:chaotic_helper/backend.dart';

Future<void> main() async {
  ${Chaotic.applicationName == null ? '' : 'Chaotic.applicationName = "${Chaotic.applicationName}";'}
  ${git ? 'Chaotic.useGit = true;' : ''}
  
  await Chaotic.clear();
}
''';
